HaDeX_GUI: HaDeX Graphical User Interface

View source: R/HaDeX_gui.R

HaDeX_GUIR Documentation

HaDeX Graphical User Interface

Description

Shows how to launch graphical user interface from HaDeXGUI package. If the GUI package is not installed, it asks user whether to install it.

Usage

HaDeX_GUI()

Value

No return value, called for side effects

Warning

Any ad-blocking software may cause malfunctions.


HaDeX2 documentation built on Feb. 9, 2026, 5:07 p.m.