add_stat_dependency: Calculates confidence limits

View source: R/add_stat_dependency.R

add_stat_dependencyR Documentation

Calculates confidence limits

Description

Returns relation with confidence limits for each peptide.

Usage

add_stat_dependency(
  calc_dat,
  confidence_level = 0.98,
  theoretical = FALSE,
  fractional = TRUE
)

Arguments

calc_dat

data produced by calculate_diff_uptake function.

confidence_level

confidence limit - from range [0, 1].

theoretical

logical, determines if values are theoretical.

fractional

logical, determines if values are fractional.

Details

This function checks if the values are statistically significant based on provided criteria using Houde test.

Value

calc_dat extended by column specifying if given peptide is relevant in given confidence limit. The value of the confidence limit is added as an attribute - as well as parameters used to calculate (theoretical/fractional).

Examples

calc_dat <- calculate_diff_uptake(alpha_dat)
result <- add_stat_dependency(calc_dat)
head(result)                            


HaDeX2 documentation built on Feb. 9, 2026, 5:07 p.m.