calculate_MHP: Calculate MHP of the peptide

calculate_MHPR Documentation

Calculate MHP of the peptide

Description

Calculate the mass of the singly charged monoisotopic (or not) molecular ion of for given peptide.

Usage

calculate_MHP(Sequence, mono = FALSE)

Arguments

Sequence

sequence of the peptide (string) or vector of sequences. Each letter of the sequence of the peptide represents different amino acid (three letter representation not allowed)

mono

logical value to determine if the mass should be monoisotopic or not. FALSE by default

Details

This function calculates the mass of the singly charged monoisotopic (or not) molecular ion for given peptide. It is the sum of the residue masses plus the masses of the terminating group (H and OH). The source of the masses can be found here: http://www.matrixscience.com/help/aa_help.html. Keep in mind that this function returns the value of an unmodified peptide.

Value

vector of numeric MHP values of provided Sequences

See Also

read_hdx calculate_state_uptake

Examples

calculate_MHP("CHERICHERILADY")
calculate_MHP("CHERICHERILADY", mono = TRUE)


HaDeX2 documentation built on Feb. 9, 2026, 5:07 p.m.