calculate_aggregated_test_results: Aggregate test result

View source: R/calculate_aggregated_test_results.R

calculate_aggregated_test_resultsR Documentation

Aggregate test result

Description

Function aggregates peptide-level information into residue level. Significance method indicates if the difference is significant or not - if the number of significant peptides over this residue is bigger than the number of insignificant.

Usage

calculate_aggregated_test_results(
  p_diff_uptake_conf_dat,
  method = c("significance", "weiss"),
  time_t = 1,
  skip_amino = 1
)

Arguments

p_diff_uptake_conf_dat

uptake data with confidence, as produced by create_p_diff_uptake_dataset_with_confidence function

method

method of aggregation: significance or weiss method

time_t

chosen time point

skip_amino

integer, indicator how many amino acids from the N-terminus should be omitted in visualization

Details

Only peptides without modification are aggregated.

Value

a data.frame object

See Also

read_hdx

Examples

p_diff_uptake_dat <- create_p_diff_uptake_dataset(alpha_dat)
p_diff_uptake_conf_dat <- create_p_diff_uptake_dataset_with_confidence(p_diff_uptake_dat)
calculate_aggregated_test_results(p_diff_uptake_conf_dat, method = "significance")
calculate_aggregated_test_results(p_diff_uptake_conf_dat, method = "weiss")


HaDeX2 documentation built on Feb. 9, 2026, 5:07 p.m.