View source: R/calculate_auc.R
| calculate_auc | R Documentation |
Calculates area under the deuterium uptake curve
calculate_auc(
uptake_dat,
protein = uptake_dat[["Protein"]][1],
state = uptake_dat[["State"]][1],
preserve_values = FALSE
)
uptake_dat |
data with deuterium uptake values,
calculated e.q. by |
protein |
chosen protein |
state |
state included in calculations |
preserve_values |
indicator if the original columns form uptake_dat should be preserve in the result |
The AUC is calculated on the data normalized to unit square by division by maximum values of exposure time and deuterium uptake, respectively.
a data.frame object
read_hdx
create_uptake_dataset
uptake_dat <- create_uptake_dataset(alpha_dat)
head(calculate_auc(uptake_dat))
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.