calculate_back_exchange: Back exchange estimation

View source: R/calculate_back_exchange.R

calculate_back_exchangeR Documentation

Back exchange estimation

Description

Calculates back-exchange for a state

Usage

calculate_back_exchange(
  dat,
  protein = dat[["Protein"]][1],
  states = unique(dat[["State"]]),
  time_100 = max(dat[["Exposure"]])
)

Arguments

dat

data imported by the read_hdx function

protein

selected protein

states

selected biological states for given protein

time_100

time point of measurement for fully deuterated sample

Details

Back-exchange is a reverse exchange phenomenon, important to acknowledge when working with HDX data. This function calculates back-exchange values for one biological state of the selected protein. For visualization of back-exchange data use plot_coverage_heatmap with displayed value specified as 'back-exchange'. For the definition of back-exchange see the 'vignette("datafiles")'.

Value

a data.frame object

See Also

read_hdx plot_coverage_heatmap

Examples

head(calculate_back_exchange(alpha_dat))


HaDeX2 documentation built on Feb. 9, 2026, 5:07 p.m.