View source: R/calculate_confidence_limit_values.R
| calculate_confidence_limit_values | R Documentation |
Calculates confidence limit values for prepared provided, based on chosen parameters.
calculate_confidence_limit_values(
diff_uptake_dat,
confidence_level = 0.98,
theoretical = FALSE,
fractional = TRUE,
n_rep = NULL
)
diff_uptake_dat |
differential data calculated using calculate_diff_uptake function |
confidence_level |
confidence level for the test, from range [0, 1] |
theoretical |
|
fractional |
|
n_rep |
number of replicates |
Function calculate_confidence_limit_values
calculates confidence limit using Houde test. The confidence limits
are calculated on whole provided dataset. If the user wishes to calculate
confidence limit for one, two or more time points, the provided data
should be adjusted accordingly.
range of confidence limit interval
Houde, D., Berkowitz, S.A., and Engen, J.R. (2011). The Utility of Hydrogen/Deuterium Exchange Mass Spectrometry in Biopharmaceutical Comparability Studies. J Pharm Sci 100, 2071–2086.
read_hdx
calculate_diff_uptake
create_diff_uptake_dataset
diff_uptake_dat <- calculate_diff_uptake(alpha_dat)
calculate_confidence_limit_values(diff_uptake_dat)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.