calculate_diff_uptake: Calculate differential uptake

View source: R/calculate_diff_uptake.R

calculate_diff_uptakeR Documentation

Calculate differential uptake

Description

Calculates differential deuterium uptake between two selected biological states.

Usage

calculate_diff_uptake(
  dat,
  protein = unique(dat[["Protein"]][1]),
  states = unique(dat[["State"]])[1:2],
  time_0 = min(dat[["Exposure"]]),
  time_t = unique(dat[["Exposure"]])[3],
  time_100 = max(dat[["Exposure"]]),
  deut_part = 0.9
)

Arguments

dat

data imported by the read_hdx function

protein

chosen protein

states

vector of two states for chosen protein. Order is important, as the deuterium uptake difference is calculated as state_1 - state_2

time_0

minimal exchange control time point of measurement [min]

time_t

time point of the measurement for which the calculations are done [min]

time_100

maximal exchange control time point of measurement [min]

deut_part

deuterium percentage in solution used in experiment, value from range [0, 1]

Details

Function calculate_diff_uptake calculates differential values based on provided criteria for peptides for chosen protein in selected states. The methods of calculation of deuterium uptake difference, fractional deuterium uptake difference with respect to minimal/maximal exchange controls or theoretical tabular values are thoroughly described in the 'Data processing' article, as well as law of propagation of uncertainty, used to calculate uncertainty.

Value

a data.frame object.

See Also

read_hdx calculate_state_uptake

Examples

diff_dat <- calculate_diff_uptake(alpha_dat)
head(diff_dat)


HaDeX2 documentation built on Feb. 9, 2026, 5:07 p.m.