calculate_exp_masses: Calculate measured mass, aggregated from the replicates of...

calculate_exp_massesR Documentation

Calculate measured mass, aggregated from the replicates of the experiment

Description

Calculate the measured mass (with the uncertainty of the measurement) as aggregated data from the replicates of the experiment.

Usage

calculate_exp_masses(dat)

Arguments

dat

data as imported by the read_hdx function

Details

Each measurement is repeated at least three times to obtain reliable result and to calculate uncertainty of the measurement. For more information on how the data is aggregated or how the uncertainty is calculated, see the documentation.

Value

a data.frame object.

See Also

read_hdx calculate_exp_masses_per_replicate calculate_state_uptake

Examples

calculate_exp_masses(alpha_dat)


HaDeX2 documentation built on Feb. 9, 2026, 5:07 p.m.