calculate_exp_masses_per_replicate: Calculate measured mass for each replicate of the experiment

View source: R/calculate_masses.R

calculate_exp_masses_per_replicateR Documentation

Calculate measured mass for each replicate of the experiment

Description

Calculate the measured mass from partial results, per each replicate of the experiment.

Usage

calculate_exp_masses_per_replicate(dat)

Arguments

dat

data as imported by the read_hdx function

Details

Each replicate of the experiment generates measurements of the mass for obtained charge values for the peptide. This is an effect of the properties of mass spectrometry, that measures the mass to charge ratio (learn more about Mass Spectrometry in the documentation). The possible charge values depend on the sequence of the peptide. The separate measurement (for each replicate in given state in given time point) can be distinguished by the 'File' value.

Value

a data.frame object.

See Also

read_hdx calculate_exp_masses calculate_state_uptake

Examples

head(calculate_exp_masses_per_replicate(alpha_dat))


HaDeX2 documentation built on Feb. 9, 2026, 5:07 p.m.