View source: R/calculate_p_value.R
| calculate_p_value | R Documentation |
Create p-value dataset
calculate_p_value(
dat,
protein = unique(dat[["Protein"]])[1],
state_1 = unique(dat[["State"]])[1],
state_2 = unique(dat[["State"]])[2],
p_adjustment_method = "none",
confidence_level = 0.98
)
dat |
data imported by the |
protein |
chosen protein. |
state_1 |
biological state for chosen protein. From this state values the second state values are subtracted to get the deuterium uptake difference. |
state_2 |
biological state for chosen protein. This state values are subtracted from the first state values to get the deuterium uptake difference. |
p_adjustment_method |
method of adjustment P-values for multiple comparisons. Possible methods: "BH" (Benjamini & Hochberg correction), "bonferroni" (Bonferroni correction) and "none" (default). |
confidence_level |
confidence level for the t-test. |
This function calculates P-value based on the supplied data. Unpaired t-Student test (with supplied parameters) is used to establish if the null hypothesis (there is no difference between measured mass values between two selected biological states) can be rejected, based on the experimental mass values from replicates of the experiment - for peptide in given time point of measurement. For the peptides that have only one replicate of the measurement (in any state) the P-value cannot be calculated and is assigned with NA value.
a data.frame object.
read_hdx
calculate_exp_masses_per_replicate
plot_volcano
create_diff_uptake_dataset
create_p_diff_uptake_dataset
p_dat <- calculate_p_value(alpha_dat)
head(p_dat)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.