calculate_peptide_kinetics: Calculate kinetics dataset

View source: R/calculate_peptide_kinetics.R

calculate_peptide_kineticsR Documentation

Calculate kinetics dataset

Description

Calculate kinetics of the hydrogen-deuteration exchange for given peptide in multiple biological states.

Usage

calculate_peptide_kinetics(
  dat,
  protein = dat[["Protein"]][1],
  sequence = dat[["Sequence"]][1],
  states = unique(dat[["State"]]),
  start = dat[["Start"]][1],
  end = dat[["End"]][1],
  time_0 = min(dat[["Exposure"]]),
  time_100 = max(dat[["Exposure"]]),
  deut_part = 0.9
)

Arguments

dat

dat data imported by the read_hdx function.

protein

chosen protein.

sequence

sequence of chosen peptide.

states

vector of states (for chosen protein), for which the calculations are done.

start

start position of chosen peptide.

end

end position of chosen peptide.

time_0

minimal exchange control time point of measurement.

time_100

maximal exchange control time point of measurement.

deut_part

deuterium percentage in solution used in experiment, value from range [0, 1].

Details

Function calculate_peptide_kinetics calculates kinetic data for chosen peptide in chosen biological states. It is a wrapper for calculate_kinetics but for multiple states. The output of this function can be visualized using plot_uptake_curve. IMPORTANT! The kinetic data is often described as deuterium uptake curve data. We use this terms interchangeable.

Value

a data.frame object.

See Also

calculate_kinetics calculate_state_uptake plot_uptake_curve

Examples

# by default calculated for the first peptide from the peptide pool
calculate_peptide_kinetics(alpha_dat)


HaDeX2 documentation built on Feb. 9, 2026, 5:07 p.m.