create_control_dataset: Create dataset with control

View source: R/create_control_dataset.R

create_control_datasetR Documentation

Create dataset with control

Description

This function adds selected experimental maximal exchange control as a measurement for all biological states.

Usage

create_control_dataset(
  dat,
  control_protein = dat[["Protein"]][1],
  control_state = dat[["State"]][1],
  control_exposure = max(dat[["Exposure"]])
)

Arguments

dat

data imported by the read_hdx function.

control_protein

maximal exchange control protein, from dat.

control_state

maximal exchange control state, from dat.

control_exposure

maximal exchange control exposure (time point of measurement), from dat.

Details

Function create_control_dataset creates a dataset (similar to the output of read_hdx function), with maximal exchange control for all the states, based on provided parameters. The other functions are operating within a state, so the control is prepared for each state. The chosen maximal exchange control is distinguishable by the value '99999' in 'Exposure' control.

Value

a data.frame object.

See Also

read_hdx calculate_state_uptake

Examples

head(create_control_dataset(alpha_dat))


HaDeX2 documentation built on Feb. 9, 2026, 5:07 p.m.