create_diff_uptake_dataset: Generate differential dataset

View source: R/create_diff_uptake_dataset.R

create_diff_uptake_datasetR Documentation

Generate differential dataset

Description

Calculates differential deuterium uptake values between two states.

Usage

create_diff_uptake_dataset(
  dat,
  protein = unique(dat[["Protein"]])[1],
  state_1 = unique(dat[["State"]])[1],
  state_2 = unique(dat[["State"]])[2],
  time_0 = min(dat[["Exposure"]]),
  time_100 = max(dat[["Exposure"]]),
  deut_part = 0.9
)

Arguments

dat

data imported by the read_hdx function.

protein

chosen protein.

state_1

biological state for chosen protein. From this state values the second state values are subtracted to get the deuterium uptake difference.

state_2

biological state for chosen protein. This state values are subtracted from the first state values to get the deuterium uptake difference.

time_0

minimal exchange control time point of measurement [min].

time_100

maximal exchange control time point of measurement [min].

deut_part

deuterium percentage in solution used in experiment, value from range [0, 1].

Details

The function create_diff_uptake_dataset generates a dataset with differential values between given biological states (state_1 - state_2). For each peptide of chosen protein for time points of measurement between minimal and maximal control time points of measurement deuterium uptake difference, fractional deuterium uptake difference with respect to controls or theoretical tabular values are calculated, with combined and propagated uncertainty. Each peptide has an ID, based on its start position. Function output can be visualized as a differential (Woods) plot, butterfly differential plot or chiclet differential plot.

Value

a data.frame object.

See Also

read_hdx calculate_diff_uptake plot_differential_butterfly plot_differential_chiclet plot_differential

Examples

diff_uptake_dat <- create_diff_uptake_dataset(alpha_dat)
head(diff_uptake_dat)


HaDeX2 documentation built on Feb. 9, 2026, 5:07 p.m.