create_kinetic_dataset: Create kinetics dataset for a list of peptides and their...

View source: R/create_kinetic_dataset.R

create_kinetic_datasetR Documentation

Create kinetics dataset for a list of peptides and their states

Description

Generates the data set of deuterium uptake between selected time points based on supplied peptide list.

Usage

create_kinetic_dataset(
  dat,
  peptide_list,
  protein = dat[["Protein"]][1],
  time_0 = min(dat[["Exposure"]]),
  time_100 = max(dat[["Exposure"]]),
  deut_part = 0.9
)

Arguments

dat

dat data imported by the read_hdx function.

peptide_list

list of peptides for the calculation.

protein

chosen protein.

time_0

minimal exchange control time point of measurement.

time_100

maximal exchange control time point of measurement.

deut_part

deuterium percentage in solution used in experiment, value from range [0, 1].

Details

This is a wrapper for calculate_kinetics, but for the peptide list instead of one peptide.

Value

a data.frame object.

See Also

calculate_kinetics calculate_state_uptake plot_uptake_curve

Examples

peptide_list <- data.frame(Sequence = c("GFGDLKSPAGL", "FGDLKSPAGL"), 
                           state = c("ALPHA_Gamma", "ALPHA_Gamma"), 
                           start = c(1, 2), end = c(11, 11))
create_kinetic_dataset(alpha_dat, peptide_list)


HaDeX2 documentation built on Feb. 9, 2026, 5:07 p.m.