View source: R/create_p_diff_uptake_dataset_with_confidence.R
| create_p_diff_uptake_dataset_with_confidence | R Documentation |
Create differential dataset with statistical validity
create_p_diff_uptake_dataset_with_confidence(
p_diff_uptake_dat,
houde_interval = NULL,
houde_interval_times = NULL,
theoretical = FALSE,
fractional = FALSE
)
p_diff_uptake_dat |
differential uptake data
alongside the P-value as calculated by
|
houde_interval |
interval value, as calculated by
|
houde_interval_times |
specified time points to be used in calculation |
theoretical |
|
fractional |
|
Function provides additional information on statistical relevance based on supplied data.
a data.frame object.
read_hdx
create_p_diff_uptake_dataset
calculate_confidence_limit_values
p_diff_uptake_dat <- create_p_diff_uptake_dataset(alpha_dat)
p_diff_uptake_dat_confidence <- create_p_diff_uptake_dataset_with_confidence(p_diff_uptake_dat)
head(p_diff_uptake_dat_confidence)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.