create_quality_control_dataset: Experiment quality control

View source: R/quality_control.R

create_quality_control_datasetR Documentation

Experiment quality control

Description

Checks how the uncertainty changes in a function of maximal exchange control time of measurement.

Usage

create_quality_control_dataset(
  dat,
  protein = dat[["Protein"]][1],
  state_1 = unique(dat[["State"]])[1],
  state_2 = unique(dat[["State"]])[2],
  time_t = unique(dat[["Exposure"]])[2],
  time_0 = min(dat[["Exposure"]]),
  deut_part = 0.9
)

Arguments

dat

data imported by the read_hdx function.

protein

chosen protein.

state_1

first biological state.

state_2

second biological state.

time_t

time point of the measurement for which the calculations are done.

time_0

minimal exchange control time point of measurement.

deut_part

deuterium percentage in solution used in experiment, value from range [0, 1].

Details

The function calculates mean uncertainty of all peptides and its uncertainty (standard error) based on given 'time_0' and 'time_t' as a function of 'time_100'. Both theoretical and experimental results for each state and their difference are supplied for comparison but only experimental calculations depends on 'time_100' variable. The results are either in form of fractional or absolute values depending on the 'fractional' parameter supplied by the user. This data can be useful for general overview of the experiment and analyze of the chosen time parameters.

Value

data.frame object with mean uncertainty per different 'time_100' value. The values are shown as percentages.

See Also

read_hdx calculate_state_uptake plot_quality_control show_quality_control_data

Examples

create_quality_control_dataset(alpha_dat)    
                           

HaDeX2 documentation built on Feb. 9, 2026, 5:07 p.m.