create_replicate_dataset: Create replicates data

create_replicate_datasetR Documentation

Create replicates data

Description

Create replicate data set suitable for replicate histogram, for one or multiple time points of measurement.

Usage

create_replicate_dataset(
  dat,
  time_t = NULL,
  protein = unique(dat[["Protein"]])[1],
  state = dat[["State"]][1]
)

Arguments

dat

data as imported by the read_hdx function.

time_t

optional, for only one time point of measurement. If value is NULL, all time point from dat are preserved.

protein

chosen protein.

state

biological state for chosen protein.

Details

The function create_replicate_dataset creates a dataset with information about how many replicates are for peptides in specific state in time points of measurement.

Value

a data.frame object.

See Also

plot_replicate_histogram show_replicate_histogram_data

Examples

create_replicate_dataset(alpha_dat)


HaDeX2 documentation built on Feb. 9, 2026, 5:07 p.m.