create_state_comparison_dataset: Creates comparison uptake dataset

View source: R/create_state_comparison_dataset.R

create_state_comparison_datasetR Documentation

Creates comparison uptake dataset

Description

Calculates deuterium uptake values for selected biological states in selected time point of measurements.

Usage

create_state_comparison_dataset(
  dat,
  protein = unique(dat[["Protein"]])[1],
  states = unique(dat[["State"]]),
  time_0 = min(dat[["Exposure"]]),
  time_t = unique(dat[["Exposure"]])[3],
  time_100 = max(dat[["Exposure"]]),
  deut_part = 0.9
)

Arguments

dat

data imported by the read_hdx function.

protein

chosen protein.

states

vector of states (for chosen protein), for which the calculations are done.

time_0

minimal exchange control time point of measurement [min].

time_t

time point of the measurement for which the calculations are done [min].

time_100

maximal exchange control time point of measurement [min].

deut_part

deuterium percentage in solution used in experiment, value from range [0, 1].

Details

Function create_state_comparison_dataset is a wrapper for calculate_state_uptake function, calls this function for all (default) or chosen states in states vector.

Value

a data.frame object.

See Also

read_hdx calculate_state_uptake

Examples

comparison_dat <- create_state_comparison_dataset(alpha_dat)
head(comparison_dat)


HaDeX2 documentation built on Feb. 9, 2026, 5:07 p.m.