create_state_uptake_dataset: Create uptake dataset for chosen state

View source: R/create_state_uptake_dataset.R

create_state_uptake_datasetR Documentation

Create uptake dataset for chosen state

Description

Calculates deuterium uptake values for one biological state.

Usage

create_state_uptake_dataset(
  dat,
  protein = unique(dat[["Protein"]])[1],
  state = (dat[["State"]])[1],
  time_0 = min(dat[dat[["Exposure"]] > 0, ][["Exposure"]]),
  time_100 = max(dat[["Exposure"]]),
  deut_part = 0.9
)

Arguments

dat

data imported by the read_hdx function.

protein

chosen protein.

state

biological state for chosen protein.

time_0

minimal exchange control time point of measurement [min].

time_100

maximal exchange control time point of measurement [min].

deut_part

deuterium percentage in solution used in experiment, value from range [0, 1].

Details

The function create_uptake_dataset generates a dataset with deuterium uptake values in different forms. For each peptide in chosen protein in chosen state for time points of measurement between minimal and maximal control time points of measurement deuterium uptake, fractional deuterium uptake with respect to controls or theoretical tabular values are calculated, with combined and propagated uncertainty. Each peptide has an ID, based on its start position. This data can be presented in a form of comparison plot, butterfly plot or chiclet plot.

Value

a data.frame object.

See Also

read_hdx calculate_state_uptake

Examples

state_uptake_dat <- create_state_uptake_dataset(alpha_dat)
head(state_uptake_dat)


HaDeX2 documentation built on Feb. 9, 2026, 5:07 p.m.