View source: R/create_uptake_dataset.R
| create_uptake_dataset | R Documentation |
Calculates deuterium uptake values for selected biological states in multiple time points of measurements.
create_uptake_dataset(
dat,
protein = unique(dat[["Protein"]])[1],
states = unique(dat[["State"]]),
time_0 = min(dat[["Exposure"]]),
time_100 = max(dat[["Exposure"]]),
deut_part = 0.9
)
dat |
data imported by the |
protein |
chosen protein. |
states |
list of biological states for chosen protein. |
time_0 |
minimal exchange control time point of measurement [min]. |
time_100 |
maximal exchange control time point of measurement [min]. |
deut_part |
deuterium percentage in solution used in experiment, value from range [0, 1]. |
Function create_uptake_dataset generates
a dataset with deuterium uptake values in different forms. For each
peptide in chosen protein in chosen states for time points of measurement
between minimal and maximal control time points of measurement deuterium
uptake, fractional deuterium uptake with respect to controls or theoretical
tabular values are calculated, with combined and propagated uncertainty.
Each peptide has an ID, based on its start position.
This function is a wrapper for create_state_uptake_dataset
but for multiple states.
The output of this function can be presented in a form of
comparison plot.
a data.frame object.
read_hdx
calculate_state_uptake
create_state_uptake_dataset
uptake_dat <- create_uptake_dataset(alpha_dat, states = c("Alpha_KSCN", "ALPHA_Gamma"))
head(uptake_dat)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.