get_protein_coverage: Get protein coverage

View source: R/getters.R

get_protein_coverageR Documentation

Get protein coverage

Description

Calculate protein coverage by the peptides in selected biological state or states.

Usage

get_protein_coverage(
  dat,
  protein = dat[["Protein"]][1],
  states = unique(dat[["State"]]),
  protein_length = NULL
)

Arguments

dat

data imported by the read_hdx function

protein

selected protein

states

selected biological states

protein_length

numeric, indicates the length of the protein. If not provided, the maximal end value from the file is used.

Details

Function get_protein_coverage calculates the percentage coverage of the protein sequence, rounded to two decimal places.

Value

a numeric percentage value (rounded to two decimal places).

See Also

read_hdx

Examples

get_protein_coverage(alpha_dat)
get_protein_coverage(alpha_dat, protein_length = 230)


HaDeX2 documentation built on Feb. 9, 2026, 5:07 p.m.