get_protein_redundancy: Get protein redundancy

View source: R/getters.R

get_protein_redundancyR Documentation

Get protein redundancy

Description

Calculates the protein redundancy in the whole experiment (all biological states).

Usage

get_protein_redundancy(dat, protein_length = NULL)

Arguments

dat

data imported by the read_hdx function.

protein_length

numeric, indicates the length of the protein. If not provided, the maximal end value from the file is used.

Details

Function get_protein_redundancy calculates the redundancy of the protein, based on provided experimental data.

Value

a numeric value.

See Also

read_hdx

Examples

get_protein_redundancy(alpha_dat)


HaDeX2 documentation built on Feb. 9, 2026, 5:07 p.m.