get_replicate_list_sd: Get replicates sd

get_replicate_list_sdR Documentation

Get replicates sd

Description

Get list of peptides with their standard deviation.

Usage

get_replicate_list_sd(
  dat,
  protein = dat[["Protein"]][1],
  state = dat[["State"]][1],
  time_t = unique(dat[["Exposure"]])[3]
)

Arguments

dat

data as imported by the read_hdx function.

protein

chosen protein.

state

biological state for chosen protein.

time_t

time point of the measurement.

Details

Function gets the pepitde list in selected state with their standard deviation of measurement, calculated from the technical replicates. It is used for selection for measurement variability plot.

Value

a data.frame object.

See Also

create_replicate_dataset

Examples

get_replicate_list_sd(alpha_dat)



HaDeX2 documentation built on Feb. 9, 2026, 5:07 p.m.