get_residue_positions: Get residue positions

View source: R/get_residue_positions.R

get_residue_positionsR Documentation

Get residue positions

Description

Get residue positions

Usage

get_residue_positions(dat)

Arguments

dat

data imported by the read_hdx function.

Details

Prepares data table for high-resolution values. It creates a long data frame with each position in the sequence accompanied by the amino acid placed in this position.

Value

a data.frame object.

Examples


# disabled due to long execution time 
get_residue_positions(alpha_dat)



HaDeX2 documentation built on Feb. 9, 2026, 5:07 p.m.