get_structure_color: Get color palette for 3D structure

View source: R/plot_aggregated_uptake_structure.R

get_structure_colorR Documentation

Get color palette for 3D structure

Description

This function provides a set of color codes associated with aggregated values to be presented on 3D structure.

Usage

get_structure_color(
  aggregated_dat,
  differential = FALSE,
  fractional = TRUE,
  theoretical = FALSE,
  time_t
)

Arguments

aggregated_dat

aggregated data, either for single uptake or differential

differential

indicator if the aggregated_dat contains differential results

fractional

indicator if fractional values are used

theoretical

indicator if theoretical values are used

time_t

time point from aggregated_dat to be shown on the structure

Value

a list

Examples


# disabled due to long execution time 

diff_uptake_dat <- create_diff_uptake_dataset(alpha_dat)
diff_aggregated_dat <- create_aggregated_diff_uptake_dataset(diff_uptake_dat)
get_structure_color(diff_aggregated_dat, 
                    differential = TRUE,
                    time_t = 1)



HaDeX2 documentation built on Feb. 9, 2026, 5:07 p.m.