new_hdx_data: Constructor of hdx_data class

View source: R/hdx_data_class.R

new_hdx_dataR Documentation

Constructor of hdx_data class

Description

Class hdx_data is the base of any calculation done in HaDeX. It structuralizes the data from the data file read by the read_hdx function. The object preserves the information of the data file origin - for now, the function accepts datafiles from DynamX2.0, DynamX3.0 and HDeXaminer. The data from the datafile is checked and put in one format suitable for the package workflow, regardless of its origin.

The structure is as follows: - Protein, character. - Start, integer. - End, integer. - Sequence, character. - MaxUptake, numeric. - MHP, numeric. - State, character. - Exposure, numeric. - File, character. - z, integer. - Inten, numeric. - Center, numeric.

The hdx_data class inherits from data.frame class, so the structure is preserved. The hdx_data object has two additional attributes: - source, character. Indicates the source of the datafile. - has_modification, logical. Indicates if the datafile has data from modified peptides.

Usage

new_hdx_data(dat, source, has_modification, n_rep)

Arguments

dat

data.frame, read from the datafile.

source

character, the source of the datafile.

has_modification

logical, indicator if there are modified peptides in the datafile.

Value

hdx_data object.


HaDeX2 documentation built on Feb. 9, 2026, 5:07 p.m.