plot_aggregated_differential_uptake: Plots aggregated uptake difference

View source: R/plot_aggregated_difference.R

plot_aggregated_differential_uptakeR Documentation

Plots aggregated uptake difference

Description

Plots aggregated uptake difference

Usage

plot_aggregated_differential_uptake(
  aggregated_diff_dat,
  fractional = TRUE,
  theoretical = FALSE,
  time_100 = max(unique(aggregated_diff_dat[["Exposure"]])),
  panels = FALSE,
  interactive = FALSE
)

Arguments

aggregated_diff_dat

aggregated differential uptake data as calculated by create_aggregated_diff_uptake_dataset

fractional

logical, determines if values are fractional

theoretical

logical, determines if values are theoretical

time_100

maximal exchange control time point of measurement [min]

panels

logical, indicator if plot should be divided into panels or not

interactive

logical, whether plot should have an interactive layer created with with ggiraph, which would add tooltips to the plot in an interactive display (HTML/Markdown documents or shiny app)

Value

a ggplot object

See Also

create_diff_uptake_dataset create_aggregated_diff_uptake_dataset

Examples


# disabled due to long execution time 

diff_uptake_dat <- create_diff_uptake_dataset(alpha_dat)
aggregated_diff_dat <- create_aggregated_diff_uptake_dataset(diff_uptake_dat)
plot_aggregated_differential_uptake(aggregated_diff_dat, panels = FALSE)
plot_aggregated_differential_uptake(aggregated_diff_dat, fractional = FALSE, 
                                    theoretical = TRUE, panels = FALSE)
plot_aggregated_differential_uptake(aggregated_diff_dat, theoretical = TRUE, 
                                    panels = TRUE)


HaDeX2 documentation built on Feb. 9, 2026, 5:07 p.m.