plot_amino_distribution: generate_amino_distribution

View source: R/plot_amino_distribution.R

plot_amino_distributionR Documentation

generate_amino_distribution

Description

Generates amino distribution based on the protein sequence and shows if the amino acid is hydrophobic or hydrophylic.

Usage

plot_amino_distribution(
  position_in_sequence,
  hydro_properties,
  protein,
  charge_colors,
  interactive = getOption("hadex_use_interactive_plots")
)

Arguments

position_in_sequence

custom format

hydro_properties

data with hydrophobic properties

protein

chosen protein

charge_colors

vector of desired colors

interactive

logical, whether plot should have an interactive layer created with with ggiraph, which would add tooltips to the plot in an interactive display (HTML/Markdown documents or shiny app).

Details

The data for this function is not packaged yet.

Value

a ggplot object.


HaDeX2 documentation built on Feb. 9, 2026, 5:07 p.m.