| plot_chiclet | R Documentation |
Chiclet plot of deuterium uptake values in time for one biological state.
plot_chiclet(
uptake_dat,
theoretical = FALSE,
fractional = FALSE,
show_uncertainty = FALSE,
interactive = getOption("hadex_use_interactive_plots")
)
uptake_dat |
produced by |
theoretical |
|
fractional |
|
show_uncertainty |
|
interactive |
|
Function plot_chiclet produces a chiclet
plot based on the same dataset as butterfly plot, as it is the different
form of presenting the same data. On X-axis there is a peptide ID. On
Y-axis are time points of measurement. Each tile for a peptide in time has
a color value representing the deuterium uptake, in a form based on
provided criteria (e.q. fractional). Each tile has a plus sign, which size
represent the uncertainty of measurement for chosen value.
a ggplot object.
create_state_uptake_dataset
state_uptake_dat <- create_state_uptake_dataset(alpha_dat)
plot_chiclet(state_uptake_dat)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.