View source: R/plot_coverage.R
| plot_coverage | R Documentation |
Plot the peptide coverage of the protein sequence
plot_coverage(
dat,
protein = dat[["Protein"]][1],
states = NULL,
show_blanks = TRUE,
interactive = getOption("hadex_use_interactive_plots")
)
dat |
data imported by the |
protein |
selected protein |
states |
selected biological states for given protein |
show_blanks |
|
interactive |
|
The function plot_coverage generates
sequence coverage plot based on experimental data for
selected protein in selected biological states. Only non-duplicated
peptides are shown on the plot, next to each other.
The aim of this plot is to see the dependence between position of the peptide on the protein sequence. Their position on y-axis does not contain any information.
a ggplot object
read_hdx
plot_position_frequency
plot_coverage(alpha_dat)
plot_coverage(alpha_dat, show_blanks = FALSE)
diff_uptake_dat <- create_diff_uptake_dataset(alpha_dat)
plot_coverage(diff_uptake_dat)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.