View source: R/plot_differential_butterfly.R
| plot_differential_butterfly | R Documentation |
Butterfly plot of differential deuterium uptake values between two biological states in time.
plot_differential_butterfly(
diff_uptake_dat = NULL,
diff_p_uptake_dat = NULL,
theoretical = FALSE,
fractional = FALSE,
show_houde_interval = FALSE,
show_tstud_confidence = FALSE,
uncertainty_type = "ribbon",
confidence_level = 0.98,
interactive = getOption("hadex_use_interactive_plots")
)
diff_uptake_dat |
data produced by |
diff_p_uptake_dat |
differential uptake data
alongside the P-value as calculated by
|
theoretical |
|
fractional |
|
show_houde_interval |
|
show_tstud_confidence |
|
uncertainty_type |
type of presenting uncertainty, possible values: "ribbon", "bars" or "bars + line" |
confidence_level |
confidence level for the test, from range [0, 1] Important if selected show_confidence_limit |
interactive |
|
Function plot_differential_butterfly generates
differential butterfly plot based on provided data and parameters. On X-axis
there is peptide ID. On the Y-axis there is deuterium uptake difference in
chosen form. Data from multiple time points of measurement is presented.
If chosen, there are confidence limits based on Houde test on provided
confidence level.
a [ggplot2::ggplot()] object.
Houde, D., Berkowitz, S.A., and Engen, J.R. (2011). The Utility of Hydrogen/Deuterium Exchange Mass Spectrometry in Biopharmaceutical Comparability Studies. J Pharm Sci 100, 2071–2086.
read_hdx
create_diff_uptake_dataset
calculate_diff_uptake
diff_uptake_dat <- create_diff_uptake_dataset(alpha_dat)
plot_differential_butterfly(diff_uptake_dat = diff_uptake_dat)
plot_differential_butterfly(diff_uptake_dat = diff_uptake_dat, show_houde_interval = TRUE)
diff_p_uptake_dat <- create_p_diff_uptake_dataset(alpha_dat)
plot_differential_butterfly(diff_p_uptake_dat = diff_p_uptake_dat, show_tstud_confidence = TRUE)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.