View source: R/plot_differential_chiclet.R
| plot_differential_chiclet | R Documentation |
Chiclet plot of differential deuterium uptake values between two biological states in time.
plot_differential_chiclet(
diff_uptake_dat = NULL,
diff_p_uptake_dat = NULL,
theoretical = FALSE,
fractional = FALSE,
show_houde_interval = FALSE,
show_tstud_confidence = FALSE,
confidence_level = 0.98,
show_uncertainty = FALSE,
interactive = getOption("hadex_use_interactive_plots")
)
diff_uptake_dat |
data produced by |
diff_p_uptake_dat |
differential uptake data
alongside the P-value as calculated by
|
theoretical |
|
fractional |
|
show_houde_interval |
|
show_tstud_confidence |
|
confidence_level |
confidence level for the test, from range [0, 1] Important if selected show_confidence_limit |
show_uncertainty |
|
interactive |
|
Function plot_differential_chiclet generates
chiclet differential plot based on provided data and parameters.
On X-axis there is a peptide ID. On Y-axis are time points
of measurement. Each tile for a peptide in time has a color value
representing the deuterium uptake difference between chosen states,
in a form based on provided criteria (e.q. fractional). Each tile has
a plus sign, which size represent the uncertainty of measurement for
chosen value.
a [ggplot2::ggplot()] object.
create_diff_uptake_dataset
calculate_diff_uptake
diff_uptake_dat <- create_diff_uptake_dataset(alpha_dat)
plot_differential_chiclet(diff_uptake_dat)
plot_differential_chiclet(diff_uptake_dat, show_houde_interval = TRUE)
diff_p_uptake_dat <- create_p_diff_uptake_dataset(alpha_dat)
plot_differential_chiclet(diff_p_uptake_dat = diff_p_uptake_dat,
show_tstud_confidence = TRUE)
plot_differential_chiclet(diff_p_uptake_dat = diff_p_uptake_dat,
show_tstud_confidence = TRUE, show_houde_interval = TRUE)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.