View source: R/plot_differential_uptake_curve.R
| plot_differential_uptake_curve | R Documentation |
Differential uptake curve for one peptide between two biological states.
plot_differential_uptake_curve(
diff_uptake_dat = NULL,
diff_p_uptake_dat = NULL,
sequence = NULL,
theoretical = FALSE,
fractional = FALSE,
uncertainty_type = "ribbon",
log_x = TRUE,
show_houde_interval = FALSE,
show_tstud_confidence = FALSE,
interactive = getOption("hadex_use_interactive_plots")
)
diff_uptake_dat |
produced by |
diff_p_uptake_dat |
differential uptake data
alongside the P-value as calculated by
|
sequence |
sequence of chosen peptide |
theoretical |
|
fractional |
|
uncertainty_type |
type of presenting uncertainty, possible values: "ribbon", "bars" or "bars + line" |
log_x |
|
show_houde_interval |
|
show_tstud_confidence |
|
interactive |
|
This plot shows the differential deuterium uptake between two biological states for selected peptides in different time points. The possibility to plot multiple differences (between state and mutant) for the peptide will be added soon.
a ggplot object.
read_hdx
create_diff_uptake_dataset
calculate_diff_uptake
diff_uptake_dat <- create_diff_uptake_dataset(alpha_dat)
plot_differential_uptake_curve(diff_uptake_dat = diff_uptake_dat, sequence = "GDLKSPAGL")
diff_p_uptake_dat <- create_p_diff_uptake_dataset(alpha_dat)
plot_differential_uptake_curve(diff_p_uptake_dat = diff_p_uptake_dat,
sequence = "GDLKSPAGL", show_houde_interval = TRUE)
plot_differential_uptake_curve(diff_p_uptake_dat = diff_p_uptake_dat,
sequence = "GDLKSPAGL", show_houde_interval = TRUE,
show_tstud_confidence = TRUE)
plot_differential_uptake_curve(diff_p_uptake_dat = diff_p_uptake_dat,
sequence = "GDLKSPAGL", show_tstud_confidence = TRUE)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.