View source: R/plot_manhattan.R
| plot_manhattan | R Documentation |
Manhattan plot with p-values from the t-Student test and peptide position.
plot_manhattan(
p_dat,
skip_amino = 0,
plot_title = NULL,
separate_times = TRUE,
times = NULL,
confidence_level = NULL,
show_confidence_limit = TRUE,
show_peptide_position = FALSE,
interactive = getOption("hadex_use_interactive_plots")
)
p_dat |
data produced by the |
skip_amino |
|
plot_title |
title for the plot. If not provided, it is constructed in a form: "Differences between state_1 and state_2" |
separate_times |
|
times |
vector of time points of measurements to be included in the plot. |
confidence_level |
confidence level for the test, from range [0, 1]. |
show_confidence_limit |
logical, indicates if the hybrid testing confidence intervals are shown. |
show_peptide_position |
|
interactive |
|
The manhattan plot presents the P-values from t-student test, to see the regions of the protein with statistically significant changes between two biological states. On X-axis there is a position in a sequence, with length of a segment of each peptide representing its length. On Y-axis there is P-value from t-Student test.
a ggplot object.
Hageman, T. S. & Weis, D. D. Reliable Identification of Significant Differences in Differential Hydrogen Exchange-Mass Spectrometry Measurements Using a Hybrid Significance Testing Approach. Anal Chem 91, 8008–8016 (2019).
read_hdx
create_p_diff_uptake_dataset
p_dat <- create_p_diff_uptake_dataset(alpha_dat)
plot_manhattan(p_dat)
plot_manhattan(p_dat, separate_times = FALSE)
plot_manhattan(p_dat, show_peptide_position = TRUE, separate_times = FALSE)
plot_manhattan(p_dat, separate_times = FALSE, show_confidence_limit = FALSE)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.