plot_overlap: Plot overlap data

plot_overlapR Documentation

Plot overlap data

Description

Generates overlapping peptide plot based on supplied data and parameters.

Usage

plot_overlap(dat, protein = dat[["Protein"]][1], state = dat[["State"]][1])

Arguments

dat

data imported by the read_hdx function.

protein

protein included in calculations

state

state included in calculations

Details

The overlap plot presents all the peptides in given state on the protein sequence. This plot is visible in GUI.

Value

a ggplot object.

See Also

read_hdx show_overlap_data

Examples

plot_overlap(alpha_dat)


HaDeX2 documentation built on Feb. 9, 2026, 5:07 p.m.