plot_overlap_distribution: Plot overlap distribution

plot_overlap_distributionR Documentation

Plot overlap distribution

Description

Generates overlap distribution plot based on supplied data and parameters.

Usage

plot_overlap_distribution(
  overlap_dist_dat,
  start = 1,
  end = max(overlap_dist_dat[["pos"]]),
  interactive = getOption("hadex_use_interactive_plots")
)

Arguments

overlap_dist_dat

produced by create_overlap_distribution_dataset function

start

start start position of chosen protein.

end

end position of chosen protein.

interactive

logical, whether plot should have an interactive layer created with with ggiraph, which would add tooltips to the plot in an interactive display (HTML/Markdown documents or shiny app).

Details

This plot presents how many times (by how many peptides) a amino position in protein sequence is covered. This plot is visible in GUI.

Value

a ggplot object.

See Also

read_hdx reconstruct_sequence create_overlap_distribution_dataset

Examples

overlap_dist_dat <- create_overlap_distribution_dataset(alpha_dat)
plot_overlap_distribution(overlap_dist_dat)


HaDeX2 documentation built on Feb. 9, 2026, 5:07 p.m.