plot_peptide_charge_measurement: Plot peptide charge measurement

plot_peptide_charge_measurementR Documentation

Plot peptide charge measurement

Description

Plot the charge measurements from replicates for peptide in specific time point.

Usage

plot_peptide_charge_measurement(
  dat,
  protein = dat[["Protein"]][1],
  state = dat[["State"]][1],
  sequence = dat[["Sequence"]][1],
  time_t = unique(dat[["Exposure"]])[3]
)

Arguments

dat

data as imported by the read_hdx function.

protein

chosen protein.

state

biological state for chosen protein.

sequence

sequence of chosen peptide.

time_t

time point of the measurement.

Details

This function shows the measurements of charge from different replicates for specific peptide in specific state in specific time point of measurement on the plot.

Value

a [ggplot2::ggplot()] object.

See Also

read_hdx show_peptide_charge_measurement

Examples

plot_peptide_charge_measurement(alpha_dat)


HaDeX2 documentation built on Feb. 9, 2026, 5:07 p.m.