| plot_peptide_mass_measurement | R Documentation |
Plot the mass measurements from replicates for peptide in specific time point.
plot_peptide_mass_measurement(
dat,
protein = dat[["Protein"]][1],
state = dat[["State"]][1],
sequence = dat[["Sequence"]][1],
show_charge_values = TRUE,
time_t = unique(dat[["Exposure"]])[3],
interactive = getOption("hadex_use_interactive_plots")
)
dat |
data produced by
|
protein |
chosen protein |
state |
biological state for chosen protein |
sequence |
sequence of chosen peptide |
show_charge_values |
|
time_t |
chosen time point |
interactive |
|
This function shows the measurements of mass from different replicates for specific peptide in specific state in specific time point of measurement on the plot. Moreover, on the plot is shown the average mass from the replicates, used later in calculations. The ribbon next to the dotted average mass indicates the uncertainty.
a [ggplot2::ggplot()] object.
read_hdx
calculate_exp_masses_per_replicate
calculate_exp_masses
calculate_state_uptake
calculate_diff_uptake
plot_peptide_mass_measurement(alpha_dat, sequence = "FGSDDEEESEEAKRLRE")
plot_peptide_mass_measurement(alpha_dat, sequence = "FGSDDEEESEEAKRLRE", show_charge_values = FALSE)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.