View source: R/plot_position_frequency.R
| plot_position_frequency | R Documentation |
Plot the frequency of coverage for protein sequence
plot_position_frequency(
dat,
protein = dat[["Protein"]][1],
state = dat[["State"]][1]
)
dat |
data as imported by the |
protein |
selected protein |
state |
selected biological state for given protein |
The function plot_position_frequency generates a
histogram of the coverage frequency in selected biological states
for selected protein.
The position frequency plot presents how many times each position of
the sequence is covered by different peptides.
a ggplot object.
read_hdx
plot_coverage
plot_position_frequency(alpha_dat)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.