| plot_replicate_histogram | R Documentation |
Plot histogram on number of replicates per peptide in one or multiple time point of measurement.
plot_replicate_histogram(
rep_dat,
time_points = FALSE,
interactive = getOption("hadex_use_interactive_plots")
)
rep_dat |
replicate data, created by
|
time_points |
|
interactive |
|
The function shows three versions of replicate
histogram, based on supplied rep_dat and time_points.
If time_points is selected, the histogram shows the number
of replicates for time points of measurement, to spot
if there were troubles with samples for specific time point of
measurement. Then, on the X-axis is Exposure (in minutes) and
on the Y-axis number of replicates.
If time_points is not selected, on the X-axis there are
peptide ID, and on the Y-axis there are numbers of replicates.
If rep_dat contains data from one time point
of measurement, the histogram colors reflect the
number of replicates to highlight the outliers.
If rep_dat contains multiple time point of
measurement, the colors help to distinguish between
them.
a [ggplot2::ggplot()] object.
create_replicate_dataset
show_replicate_histogram_data
rep_dat <- create_replicate_dataset(alpha_dat)
plot_replicate_histogram(rep_dat)
plot_replicate_histogram(rep_dat, time_points = TRUE)
rep_dat <- create_replicate_dataset(alpha_dat, time_t = 0.167)
plot_replicate_histogram(rep_dat)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.