View source: R/plot_replicate_mass_uptake.R
| plot_replicate_mass_uptake | R Documentation |
Plot the mass uptake curve for selected peptide to see the difference between replicates.
plot_replicate_mass_uptake(
dat,
protein = dat[["Protein"]][1],
state = dat[["State"]][1],
sequence = dat[["Sequence"]][1],
aggregated = FALSE,
log_x = TRUE,
interactive = getOption("hadex_use_interactive_plots")
)
dat |
data imported by the |
protein |
selected protein |
state |
selected biological state for given protein |
sequence |
selected peptide sequence for given protein in given biological state |
aggregated |
|
log_x |
|
interactive |
|
The function plot_replicate_mass_uptake
generates a plot showing the mass uptake for selected protein
in replicates of the experiments. The values can be presented
in two ways: as aggregated values for each replicate, or before
aggregation - measured values for charge values within a replicate.
The mass uptake is generated by subtracting the MHP mass of a peptide
from measured mass and the mass uptake is presented in Daltons.
a ggplot object.
read_hdx
calculate_exp_masses_per_replicate
plot_replicate_mass_uptake(alpha_dat)
plot_replicate_mass_uptake(alpha_dat, aggregated = TRUE)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.