View source: R/plot_state_comparison.R
| plot_state_comparison | R Documentation |
Comparison plot of deuterium uptake values in time point for biological states.
plot_state_comparison(
uptake_dat,
skip_amino = 0,
theoretical = FALSE,
fractional = FALSE,
line_size = 1.5,
all_times = FALSE,
time_t = NULL,
interactive = getOption("hadex_use_interactive_plots")
)
uptake_dat |
data produced by |
skip_amino |
|
theoretical |
|
fractional |
|
line_size |
line size for the plot |
all_times |
|
time_t |
chosen time point |
interactive |
|
The function plot_state_comparison generates
a comparison plot, presenting deuterium uptake values of peptides
from selected protein in selected biological states at one time point
of measurement at once.
On X-axis there is a position in a sequence, with length of a segment
of each peptide representing its length. On Y-axis there
is deuterium uptake in selected form. Error bars represents the combined
and propagated uncertainty.
a ggplot object
read_hdx
calculate_state_uptake
uptake_dat <- calculate_state_uptake(alpha_dat)
plot_state_comparison(uptake_dat)
plot_state_comparison(uptake_dat, all_times = TRUE)
plot_state_comparison(uptake_dat, fractional = TRUE, all_times = TRUE)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.