View source: R/plot_uncertainty.R
| plot_uncertainty | R Documentation |
Plot the uncertainty of the mass measurements - for aggregated data or before aggregation - to see if there is a region with uncertainty higher than acceptable
plot_uncertainty(
dat,
protein = dat[["Protein"]][1],
state = dat[["State"]][1],
skip_amino = 0,
aggregated = TRUE,
separate_times = TRUE,
show_threshold = TRUE,
interactive = getOption("hadex_use_interactive_plots")
)
dat |
data imported by the |
protein |
selected protein |
state |
selected biological state for given protein |
skip_amino |
|
aggregated |
|
separate_times |
|
show_threshold |
|
interactive |
|
The function plot_uncertainty generates
a plot of uncertainty of mass measurement of each peptide from
selected protein in selected biological state. The values can be presented
in two ways: as aggregated values for each replicate, or before
aggregation - measured values for charge values within a replicate.
On X-axis there is a position in a sequence, with length of a segment
of each peptide representing its length. On Y-axis there
is uncertainty of the measurement in Daltons.
The threshold is set to 1 Da, as this value is associated with exchange.
a ggplot object.
read_hdx
calculate_exp_masses
plot_uncertainty(alpha_dat)
plot_uncertainty(alpha_dat, aggregated = FALSE)
plot_uncertainty(alpha_dat, aggregated = FALSE, separate_times = FALSE)
plot_uncertainty(alpha_dat, skip_amino = 1)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.