| plot_volcano | R Documentation |
Volcano plot for differential deuterium uptake between two biological states
plot_volcano(
p_dat,
state_1 = "",
state_2 = "",
adjust_axes = TRUE,
show_confidence_limits = FALSE,
confidence_level = 0.98,
color_times = TRUE,
show_insignificant_grey = FALSE,
hide_insignificant = FALSE,
fractional = FALSE,
theoretical = FALSE,
interactive = getOption("hadex_use_interactive_plots")
)
p_dat |
data produced by the |
state_1 |
selected biological state for given protein |
state_2 |
selected biological state for given protein |
adjust_axes |
|
show_confidence_limits |
|
confidence_level |
confidence level for the test, from range [0, 1]. It should be the same as used to prepare p_dat |
color_times |
|
show_insignificant_grey |
|
hide_insignificant |
|
fractional |
|
theoretical |
|
interactive |
|
The function plot_volcano generates the
volcano plot based on supplied p_dat.
On X-axis there is differential deuterium uptake in selected form.
On Y-axis there is the P-value from t-Student test between two
biological states. Based on selected confidence level, the confidence
limits are calculated to indicate statistically significant values -
shown as red dotted lines. The values that are in upper left and right
corners pass the hybrid test.
a ggplot object.
Hageman, T. S. & Weis, D. D. Reliable Identification of Significant Differences in Differential Hydrogen Exchange-Mass Spectrometry Measurements Using a Hybrid Significance Testing Approach. Anal Chem 91, 8008–8016 (2019).
Houde, D., Berkowitz, S.A., and Engen, J.R. (2011). The Utility of Hydrogen/Deuterium Exchange Mass Spectrometry in Biopharmaceutical Comparability Studies. J Pharm Sci 100, 2071–2086.
create_p_diff_uptake_dataset
p_dat <- create_p_diff_uptake_dataset(alpha_dat)
plot_volcano(p_dat, show_confidence_limits = TRUE)
plot_volcano(p_dat, show_confidence_limits = TRUE, show_insignificant_grey = TRUE)
plot_volcano(p_dat, show_confidence_limits = TRUE, hide_insignificant = TRUE)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.