reconstruct_sequence: Reconstruct protein sequence

View source: R/reconstruct_sequence.R

reconstruct_sequenceR Documentation

Reconstruct protein sequence

Description

Reconstruct protein sequence from experimental data

Usage

reconstruct_sequence(
  dat,
  protein = dat[["Protein"]][1],
  states = unique(dat[["State"]]),
  end = NULL
)

Arguments

dat

data read by read_hdx

protein

selected protein

states

selected biological states for given protein

end

numeric, end position of the protein

Details

The function reconstruct_sequence generates protein sequence from supplied experimental data. For a position not covered, letter x is shown. If the C-terminus of protein is not covered, there is a possibility to manually fix the protein length by passing a value to the 'end' parameter.

Value

a character object.

See Also

read_hdx

Examples

reconstruct_sequence(alpha_dat)


HaDeX2 documentation built on Feb. 9, 2026, 5:07 p.m.