show_diff_uptake_data: Differential deuterium uptake data

View source: R/show_diff_uptake_data.R

show_diff_uptake_dataR Documentation

Differential deuterium uptake data

Description

Present differential deuterium uptake values in selected form

Usage

show_diff_uptake_data(
  diff_uptake_dat,
  theoretical = FALSE,
  fractional = FALSE,
  renamed = TRUE
)

Arguments

diff_uptake_dat

data produced by create_diff_uptake_dataset function

theoretical

logical, indicator if values are calculated using theoretical controls

fractional

logical, indicator if values are shown in fractional form

renamed

logical, indicator if the names of the columns are renamed to user-friendly ones. Currently FALSE not implemented.

Details

The function show_uptake_data generates a subsets of the diff_uptake_dat based on selected parameters. The numerical values are rounded to 4 places. The names of columns are changed to user-friendly ones.

Value

a data.frame object

See Also

read_hdx create_diff_uptake_dataset

Examples

diff_uptake_dat <- create_diff_uptake_dataset(alpha_dat)
head(show_diff_uptake_data(diff_uptake_dat))


HaDeX2 documentation built on Feb. 9, 2026, 5:07 p.m.