show_diff_uptake_data_confidence: Differential uptake data with confidence

show_diff_uptake_data_confidenceR Documentation

Differential uptake data with confidence

Description

Present differential deuterium uptake values in selected form, accompanied by the significance

Usage

show_diff_uptake_data_confidence(
  diff_uptake_dat,
  theoretical = FALSE,
  fractional = FALSE,
  confidence_level = 0.98,
  hybrid = FALSE
)

Arguments

diff_uptake_dat

data produced by create_diff_uptake_dataset function

theoretical

logical, indicator if values are calculated using theoretical controls

fractional

logical, indicator if values are shown in fractional form

confidence_level

confidence level for the test, from range [0, 1].

hybrid

logical, indicator if the hybrid testing was applied in diff_uptake_dat.

Details

The function show_uptake_data generates a subsets of the uptake dat based on selected parameters. It contains the information if the value is statistically significant at selected confidence level. The numerical values are rounded to 4 places. The names of columns are changed to user-friendly ones.

Value

a data.frame object

See Also

create_diff_uptake_dataset plot_differential

Examples

diff_uptake_dat <- create_diff_uptake_dataset(alpha_dat)
show_diff_uptake_data_confidence(diff_uptake_dat)


HaDeX2 documentation built on Feb. 9, 2026, 5:07 p.m.