show_overlap_data: Show data on peptide overlap

View source: R/overlaps.R

show_overlap_dataR Documentation

Show data on peptide overlap

Description

Presents peptide overlap on protein sequence data, based on the supplied parameters.

Usage

show_overlap_data(
  dat,
  protein = dat[["Protein"]][1],
  state = dat[["State"]][1],
  start = min(dat[["Start"]]),
  end = max(dat[["End"]])
)

Arguments

dat

data imported by the read_hdx function.

protein

chosen protein.

state

biological state for chosen protein.

start

start position of chosen protein.

end

end position of chosen protein.

Details

The data frame presents all the peptides in given state, with its start and end position on the protein sequence. This data is available in the GUI.

Value

a data.frame object.

See Also

read_hdx plot_overlap

Examples

show_overlap_data(alpha_dat)


HaDeX2 documentation built on Feb. 9, 2026, 5:07 p.m.