show_peptide_mass_measurement: Show peptide mass measurement

View source: R/replicates.R

show_peptide_mass_measurementR Documentation

Show peptide mass measurement

Description

Show the mass measurements from replicates for peptide in specific time point.

Usage

show_peptide_mass_measurement(
  rep_mass_dat,
  protein = rep_mass_dat[["Protein"]][1],
  state = rep_mass_dat[["State"]][1],
  sequence = rep_mass_dat[["Sequence"]][1],
  time_t = unique(rep_mass_dat[["Exposure"]])[3]
)

Arguments

rep_mass_dat

data produced by calculate_exp_masses_per_replicate function.

protein

chosen protein.

state

biological state for chosen protein.

sequence

sequence of chosen peptide.

time_t

time point of the measurement.

Details

This function shows the measurements of mass from different replicates for specific peptide in specific state in specific time point of measurement.

Value

a data.frame object.

See Also

read_hdx calculate_exp_masses_per_replicate calculate_exp_masses calculate_state_uptake calculate_diff_uptake

Examples

rep_mass_dat <- calculate_exp_masses_per_replicate(alpha_dat)
show_peptide_mass_measurement(rep_mass_dat)


HaDeX2 documentation built on Feb. 9, 2026, 5:07 p.m.