show_replicate_histogram_data: Show replicate data

show_replicate_histogram_dataR Documentation

Show replicate data

Description

Show histogram data on number of replicates per peptide in one or multiple time point of measurement.

Usage

show_replicate_histogram_data(rep_dat)

Arguments

rep_dat

replicate data, created by create_replicate_dataset function.

Details

The function shows the information about number of replicates for peptides in one or multiple time point of measurement, depends on supplied data.

Value

a data.frame object.

See Also

create_replicate_dataset plot_replicate_histogram

Examples

rep_dat <- create_replicate_dataset(alpha_dat)
show_replicate_histogram_data(rep_dat)


HaDeX2 documentation built on Feb. 9, 2026, 5:07 p.m.