show_summary_data: Summary data

show_summary_dataR Documentation

Summary data

Description

Show summary table

Usage

show_summary_data(
  dat,
  confidence_level = "",
  protein_length = max(dat[["End"]])
)

Arguments

dat

data imported by the read_hdx function

confidence_level

confidence level for the test, from range [0, 1].

protein_length

the length of the protein sequence

Details

The format in the table is suggested by the community and should be provided for experimental data.

Value

a data.table object

References

Masson, G.R., Burke, J.E., Ahn, N.G., Anand, G.S., Borchers, C., Brier, S., Bou-Assaf, G.M., Engen, J.R., Englander, S.W., Faber, J., et al. (2019). Recommendations for performing, interpreting and reporting hydrogen deuterium exchange mass spectrometry (HDX-MS) experiments. Nat Methods 16, 595–602

See Also

read_hdx

Examples

show_summary_data(alpha_dat)


HaDeX2 documentation built on Feb. 9, 2026, 5:07 p.m.