show_uc_data: Deuterium uptake curve data

View source: R/show_kinetic_data.R

show_uc_dataR Documentation

Deuterium uptake curve data

Description

Present deuterium uptake curve data

Usage

show_uc_data(uc_dat, theoretical = FALSE, fractional = FALSE)

Arguments

uc_dat

calculated kinetic data by calculate_kinetics or calculate_peptide_kinetics or create_kinetic_dataset function

theoretical

logical, indicator if values are calculated using theoretical controls

fractional

logical, indicator if values are shown in fractional form

Details

The function show_uptake_data generates a subsets of the uc_dat based on selected parameters. The numerical values are rounded to 4 places. The names of columns are changed to user-friendly ones.

Value

a data.frame object

See Also

read_hdx calculate_kinetics calculate_peptide_kinetics

Examples

uc_dat <- calculate_kinetics(alpha_dat,
                             sequence = "GFGDLKSPAGL", 
                             state = "ALPHA_Gamma",
                             start = 1, end = 11)
show_uc_data(uc_dat)


HaDeX2 documentation built on Feb. 9, 2026, 5:07 p.m.