show_uptake_data: Deuterium uptake data

View source: R/show_data.R

show_uptake_dataR Documentation

Deuterium uptake data

Description

Present deuterium uptake values in selected form

Usage

show_uptake_data(
  uptake_dat,
  theoretical = FALSE,
  fractional = FALSE,
  renamed = TRUE
)

Arguments

uptake_dat

data produced by create_uptake_dataset function or create_state_uptake_dataset

theoretical

logical, indicator if values are calculated using theoretical controls

fractional

logical, indicator if values are shown in fractional form

renamed

logical, indicator if the names of the columns are renamed to user-friendly ones. Currently FALSE not implemented.

Details

The function show_uptake_data generates a subsets of the uptake_dat based on selected parameters. The numerical values are rounded to 4 places. The names of columns are changed to user-friendly ones.

Value

a data.frame object

See Also

read_hdx create_uptake_dataset

Examples

uptake_dat <- create_uptake_dataset(alpha_dat)
show_uptake_data(uptake_dat)


HaDeX2 documentation built on Feb. 9, 2026, 5:07 p.m.