View source: R/add_stat_dependency.R
| add_stat_dependency | R Documentation |
Returns relation with confidence limits for each peptide.
add_stat_dependency(
calc_dat,
confidence_level = 0.98,
theoretical = FALSE,
fractional = TRUE
)
calc_dat |
data produced by |
confidence_level |
confidence limit - from range [0, 1]. |
theoretical |
|
fractional |
|
This function checks if the values are statistically significant based on provided criteria using Houde test.
calc_dat extended by column specifying if given peptide is relevant in given confidence limit. The value of the confidence limit is added as an attribute - as well as parameters used to calculate (theoretical/fractional).
calc_dat <- calculate_diff_uptake(alpha_dat)
result <- add_stat_dependency(calc_dat)
head(result)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.