| calculate_MHP | R Documentation |
Calculate the mass of the singly charged monoisotopic (or not) molecular ion of for given peptide.
calculate_MHP(Sequence, mono = FALSE)
Sequence |
sequence of the peptide (string) or vector of sequences. Each letter of the sequence of the peptide represents different amino acid (three letter representation not allowed) |
mono |
logical value to determine if the mass should be monoisotopic or not. FALSE by default |
This function calculates the mass of the singly charged monoisotopic (or not) molecular ion for given peptide. It is the sum of the residue masses plus the masses of the terminating group (H and OH). The source of the masses can be found here: http://www.matrixscience.com/help/aa_help.html. Keep in mind that this function returns the value of an unmodified peptide.
vector of numeric MHP values of provided Sequences
read_hdx
calculate_state_uptake
calculate_MHP("CHERICHERILADY")
calculate_MHP("CHERICHERILADY", mono = TRUE)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.