View source: R/calculate_aggregated_test_results.R
| calculate_aggregated_test_results | R Documentation |
Function aggregates peptide-level information into residue level. Significance method indicates if the difference is significant or not - if the number of significant peptides over this residue is bigger than the number of insignificant.
calculate_aggregated_test_results(
p_diff_uptake_conf_dat,
method = c("significance", "weiss"),
time_t = 1,
skip_amino = 1
)
p_diff_uptake_conf_dat |
uptake data with confidence,
as produced by |
method |
method of aggregation: significance or weiss method |
time_t |
chosen time point |
skip_amino |
|
Only peptides without modification are aggregated.
a data.frame object
read_hdx
p_diff_uptake_dat <- create_p_diff_uptake_dataset(alpha_dat)
p_diff_uptake_conf_dat <- create_p_diff_uptake_dataset_with_confidence(p_diff_uptake_dat)
calculate_aggregated_test_results(p_diff_uptake_conf_dat, method = "significance")
calculate_aggregated_test_results(p_diff_uptake_conf_dat, method = "weiss")
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.