View source: R/calculate_back_exchange.R
| calculate_back_exchange | R Documentation |
Calculates back-exchange for a state
calculate_back_exchange(
dat,
protein = dat[["Protein"]][1],
states = unique(dat[["State"]]),
time_100 = max(dat[["Exposure"]])
)
dat |
data imported by the |
protein |
selected protein |
states |
selected biological states for given protein |
time_100 |
time point of measurement for fully deuterated sample |
Back-exchange is a reverse exchange phenomenon, important
to acknowledge when working with HDX data. This function calculates
back-exchange values for one biological state of the selected protein.
For visualization of back-exchange data use plot_coverage_heatmap
with displayed value specified as 'back-exchange'.
For the definition of back-exchange see the 'vignette("datafiles")'.
a data.frame object
read_hdx
plot_coverage_heatmap
head(calculate_back_exchange(alpha_dat))
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.