| calculate_exp_masses | R Documentation |
Calculate the measured mass (with the uncertainty of the measurement) as aggregated data from the replicates of the experiment.
calculate_exp_masses(dat)
dat |
data as imported by the |
Each measurement is repeated at least three times to obtain reliable result and to calculate uncertainty of the measurement. For more information on how the data is aggregated or how the uncertainty is calculated, see the documentation.
a data.frame object.
read_hdx
calculate_exp_masses_per_replicate
calculate_state_uptake
calculate_exp_masses(alpha_dat)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.