View source: R/calculate_masses.R
| calculate_exp_masses_per_replicate | R Documentation |
Calculate the measured mass from partial results, per each replicate of the experiment.
calculate_exp_masses_per_replicate(dat)
dat |
data as imported by the |
Each replicate of the experiment generates measurements of the mass for obtained charge values for the peptide. This is an effect of the properties of mass spectrometry, that measures the mass to charge ratio (learn more about Mass Spectrometry in the documentation). The possible charge values depend on the sequence of the peptide. The separate measurement (for each replicate in given state in given time point) can be distinguished by the 'File' value.
a data.frame object.
read_hdx
calculate_exp_masses
calculate_state_uptake
head(calculate_exp_masses_per_replicate(alpha_dat))
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.