View source: R/calculate_kinetics.R
| calculate_kinetics | R Documentation |
Calculate kinetics of the hydrogen-deuteration exchange for given peptide in given state.
calculate_kinetics(
dat,
protein = dat[["Protein"]][1],
sequence = dat[["Sequence"]][1],
state = dat[["State"]][1],
start = dat[["Start"]][1],
end = dat[["End"]][1],
time_0 = min(dat[["Exposure"]]),
time_100 = max(dat[["Exposure"]]),
deut_part = 0.9
)
dat |
dat data imported by the |
protein |
protein chosen protein. |
sequence |
sequence of chosen peptide. |
state |
biological state of chosen peptide. |
start |
start position of chosen peptide. |
end |
end position of chosen peptide. |
time_0 |
minimal exchange control time point of measurement. |
time_100 |
maximal exchange control time point of measurement. |
deut_part |
deuterium percentage in solution used in experiment, value from range [0, 1]. |
The function calculates deuteration data for all available data points
for given peptide in chosen biological state..
All four variants (relative & theoretical combinations) of deuterium uptake computations
are supported. Manual correction of percentage of deuterium the protein was exposed
to during the exchange in theoretical calculations is provided.
To visualize obtained data we recommend using plot_uptake_curve function.
The first version doesn't support filled Modification and Fragment columns.
IMPORTANT! The kinetic data is often described as deuterium uptake curve data.
We use this terms interchangeable.
a data.frame object.
read_hdx
calculate_state_uptake
plot_uptake_curve
# by default: for the first peptide
calculate_kinetics(alpha_dat)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.