View source: R/calculate_peptide_kinetics.R
| calculate_peptide_kinetics | R Documentation |
Calculate kinetics of the hydrogen-deuteration exchange for given peptide in multiple biological states.
calculate_peptide_kinetics(
dat,
protein = dat[["Protein"]][1],
sequence = dat[["Sequence"]][1],
states = unique(dat[["State"]]),
start = dat[["Start"]][1],
end = dat[["End"]][1],
time_0 = min(dat[["Exposure"]]),
time_100 = max(dat[["Exposure"]]),
deut_part = 0.9
)
dat |
dat data imported by the |
protein |
chosen protein. |
sequence |
sequence of chosen peptide. |
states |
vector of states (for chosen protein), for which the calculations are done. |
start |
start position of chosen peptide. |
end |
end position of chosen peptide. |
time_0 |
minimal exchange control time point of measurement. |
time_100 |
maximal exchange control time point of measurement. |
deut_part |
deuterium percentage in solution used in experiment, value from range [0, 1]. |
Function calculate_peptide_kinetics calculates
kinetic data for chosen peptide in chosen biological states.
It is a wrapper for calculate_kinetics but for multiple
states.
The output of this function can be visualized using plot_uptake_curve.
IMPORTANT! The kinetic data is often described as deuterium uptake curve data.
We use this terms interchangeable.
a data.frame object.
calculate_kinetics
calculate_state_uptake
plot_uptake_curve
# by default calculated for the first peptide from the peptide pool
calculate_peptide_kinetics(alpha_dat)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.