View source: R/calculate_state_uptake.R
| calculate_state_uptake | R Documentation |
Calculates deuteration uptake based on supplied parameters.
calculate_state_uptake(
dat,
protein = unique(dat[["Protein"]])[1],
state = unique(dat[["State"]])[1],
time_0 = min(dat[dat[["Exposure"]] > 0, ][["Exposure"]]),
time_t = unique(dat[["Exposure"]])[3],
time_100 = max(dat[["Exposure"]]),
deut_part = 0.9
)
dat |
data as imported by the |
protein |
chosen protein |
state |
state included in calculations |
time_0 |
minimal exchange control |
time_t |
chosen time point |
time_100 |
maximal exchange control |
deut_part |
percentage of deuterium the protein was exposed to, value in range [0, 1] |
The function calculate_state_uptake calculates deuterium uptake
(in different forms) for all of the peptides in given protein in given state based
on supplied parameters: 'time_0', 'time_100' and 'time_t'. All four variants
(fractional) are supplied (mean values and uncertainty). Manual correction of
percentage of deuterium the protein was exposed to during the exchange
in theoretical calculations is provided.
Methods of calculation and uncertainty are profoundly discussed in the vignette.
a data.frame object
read_hdx
create_uptake_dataset
calculate_confidence_limit_values
add_stat_dependency
head(calculate_state_uptake(alpha_dat))
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.