View source: R/create_control_dataset.R
| create_control_dataset | R Documentation |
This function adds selected experimental maximal exchange control as a measurement for all biological states.
create_control_dataset(
dat,
control_protein = dat[["Protein"]][1],
control_state = dat[["State"]][1],
control_exposure = max(dat[["Exposure"]])
)
dat |
data imported by the |
control_protein |
maximal exchange control protein, from dat. |
control_state |
maximal exchange control state, from dat. |
control_exposure |
maximal exchange control exposure (time point of measurement), from dat. |
Function create_control_dataset
creates a dataset (similar to the output of read_hdx
function), with maximal exchange control for all the states,
based on provided parameters. The other functions are operating
within a state, so the control is prepared for each state.
The chosen maximal exchange control is distinguishable by the value
'99999' in 'Exposure' control.
a data.frame object.
read_hdx
calculate_state_uptake
head(create_control_dataset(alpha_dat))
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.