View source: R/create_kinetic_dataset.R
| create_kinetic_dataset | R Documentation |
Generates the data set of deuterium uptake between selected time points based on supplied peptide list.
create_kinetic_dataset(
dat,
peptide_list,
protein = dat[["Protein"]][1],
time_0 = min(dat[["Exposure"]]),
time_100 = max(dat[["Exposure"]]),
deut_part = 0.9
)
dat |
dat data imported by the |
peptide_list |
list of peptides for the calculation. |
protein |
chosen protein. |
time_0 |
minimal exchange control time point of measurement. |
time_100 |
maximal exchange control time point of measurement. |
deut_part |
deuterium percentage in solution used in experiment, value from range [0, 1]. |
This is a wrapper for calculate_kinetics, but for
the peptide list instead of one peptide.
a data.frame object.
calculate_kinetics
calculate_state_uptake
plot_uptake_curve
peptide_list <- data.frame(Sequence = c("GFGDLKSPAGL", "FGDLKSPAGL"),
state = c("ALPHA_Gamma", "ALPHA_Gamma"),
start = c(1, 2), end = c(11, 11))
create_kinetic_dataset(alpha_dat, peptide_list)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.