View source: R/create_p_diff_uptake_dataset.R
| create_p_diff_uptake_dataset | R Documentation |
Creates differential deuterium uptake dataset with P-value from t-Student test for selected two biological states.
create_p_diff_uptake_dataset(
dat,
diff_uptake_dat = NULL,
protein = unique(dat[["Protein"]])[1],
state_1 = unique(dat[["State"]])[1],
state_2 = unique(dat[["State"]])[2],
p_adjustment_method = "none",
confidence_level = 0.98,
time_0 = min(dat[["Exposure"]]),
time_100 = max(dat[["Exposure"]]),
deut_part = 0.9
)
dat |
data imported by the |
diff_uptake_dat |
differential uptake data |
protein |
chosen protein. |
state_1 |
biological state for chosen protein. From this state values the second state values are subtracted to get the deuterium uptake difference. |
state_2 |
biological state for chosen protein. This state values are subtracted from the first state values to get the deuterium uptake difference. |
p_adjustment_method |
method of adjustment P-values for multiple comparisons. Possible methods: "BH" (Benjamini & Hochberg correction), "bonferroni" (Bonferroni correction) and "none" (default). |
confidence_level |
confidence level for the t-test. |
time_0 |
minimal exchange control time point of measurement [min]. |
time_100 |
maximal exchange control time point of measurement [min]. |
deut_part |
deuterium percentage in solution used in experiment, value from range [0, 1]. |
For peptides in all of the time points of measurement (except for minimal and maximal exchange control) the deuterium uptake difference between state_1 and state_2 is calculated, with its uncertainty (combined and propagated as described in 'Data processing' article). For each peptide in time point the P-value is calculated using unpaired t-test. The deuterium uptake difference is calculated as the difference of measured masses in a given time point for two states. The tested hypothesis is that the mean masses for states from the replicates of the experiment are similar. The P-values indicates if the null hypothesis can be rejected - rejection of the hypothesis means that the difference between states is statistically significant at provided confidence level. The P-values can be adjusted using the provided method.
a data.frame object with calculated deuterium uptake difference
in different forms with their uncertainty, P-value and -log(P-value) for the peptides
from the provided data.
Hageman, T. S. & Weis, D. D. Reliable Identification of Significant Differences in Differential Hydrogen Exchange-Mass Spectrometry Measurements Using a Hybrid Significance Testing Approach. Anal Chem 91, 8008–8016 (2019).
read_hdx
calculate_exp_masses_per_replicate
p_diff_uptake_dat <- create_p_diff_uptake_dataset(alpha_dat)
head(p_diff_uptake_dat)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.