View source: R/quality_control.R
| create_quality_control_dataset | R Documentation |
Checks how the uncertainty changes in a function of maximal exchange control time of measurement.
create_quality_control_dataset(
dat,
protein = dat[["Protein"]][1],
state_1 = unique(dat[["State"]])[1],
state_2 = unique(dat[["State"]])[2],
time_t = unique(dat[["Exposure"]])[2],
time_0 = min(dat[["Exposure"]]),
deut_part = 0.9
)
dat |
data imported by the |
protein |
chosen protein. |
state_1 |
first biological state. |
state_2 |
second biological state. |
time_t |
time point of the measurement for which the calculations are done. |
time_0 |
minimal exchange control time point of measurement. |
deut_part |
deuterium percentage in solution used in experiment, value from range [0, 1]. |
The function calculates mean uncertainty of all peptides and its uncertainty (standard error) based on given 'time_0' and 'time_t' as a function of 'time_100'. Both theoretical and experimental results for each state and their difference are supplied for comparison but only experimental calculations depends on 'time_100' variable. The results are either in form of fractional or absolute values depending on the 'fractional' parameter supplied by the user. This data can be useful for general overview of the experiment and analyze of the chosen time parameters.
data.frame object with mean uncertainty per different
'time_100' value.
The values are shown as percentages.
read_hdx
calculate_state_uptake
plot_quality_control
show_quality_control_data
create_quality_control_dataset(alpha_dat)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.