| get_peptide_sequence | R Documentation |
Gets the peptide sequence based on selected parameters (start and end position, modification).
get_peptide_sequence(
dat,
protein = dat[["Protein"]][1],
start,
end,
modification = FALSE
)
dat |
any data frame that contains following information: protein, sequence, start, end, modification. |
protein |
chosen protein. |
start |
start position of the peptide of interest. |
end |
end position of the peptide of interest. |
modification |
logical value to indicate if peptide of interest has modification or not. |
Function returns peptide sequence for selected parameters. Peptide sequence is often required to properly identify peptide of interest, and to avoid mistakes sequence is returned by the function. Moreover, function uses the modification value to select peptide sequence.
a character value.
read_hdx
get_peptide_sequence(alpha_dat, start = 1, end = 11)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.