| get_protein_coverage | R Documentation |
Calculate protein coverage by the peptides in selected biological state or states.
get_protein_coverage(
dat,
protein = dat[["Protein"]][1],
states = unique(dat[["State"]]),
protein_length = NULL
)
dat |
data imported by the |
protein |
selected protein |
states |
selected biological states |
protein_length |
|
Function get_protein_coverage calculates the
percentage coverage of the protein sequence, rounded to two decimal places.
a numeric percentage value (rounded to two decimal places).
read_hdx
get_protein_coverage(alpha_dat)
get_protein_coverage(alpha_dat, protein_length = 230)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.