| get_replicate_list_sd | R Documentation |
Get list of peptides with their standard deviation.
get_replicate_list_sd(
dat,
protein = dat[["Protein"]][1],
state = dat[["State"]][1],
time_t = unique(dat[["Exposure"]])[3]
)
dat |
data as imported by the |
protein |
chosen protein. |
state |
biological state for chosen protein. |
time_t |
time point of the measurement. |
Function gets the pepitde list in selected state with their standard deviation of measurement, calculated from the technical replicates. It is used for selection for measurement variability plot.
a data.frame object.
create_replicate_dataset
get_replicate_list_sd(alpha_dat)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.