View source: R/get_residue_positions.R
| get_residue_positions | R Documentation |
Get residue positions
get_residue_positions(dat)
dat |
data imported by the |
Prepares data table for high-resolution values. It creates a long data frame with each position in the sequence accompanied by the amino acid placed in this position.
a data.frame object.
# disabled due to long execution time
get_residue_positions(alpha_dat)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.