View source: R/plot_aggregated_uptake_structure.R
| get_structure_color | R Documentation |
This function provides a set of color codes associated with aggregated values to be presented on 3D structure.
get_structure_color(
aggregated_dat,
differential = FALSE,
fractional = TRUE,
theoretical = FALSE,
time_t
)
aggregated_dat |
aggregated data, either for single uptake or differential |
differential |
indicator if the aggregated_dat contains differential results |
fractional |
indicator if fractional values are used |
theoretical |
indicator if theoretical values are used |
time_t |
time point from aggregated_dat to be shown on the structure |
a list
# disabled due to long execution time
diff_uptake_dat <- create_diff_uptake_dataset(alpha_dat)
diff_aggregated_dat <- create_aggregated_diff_uptake_dataset(diff_uptake_dat)
get_structure_color(diff_aggregated_dat,
differential = TRUE,
time_t = 1)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.