View source: R/plot_amino_distribution.R
| plot_amino_distribution | R Documentation |
Generates amino distribution based on the protein sequence and shows if the amino acid is hydrophobic or hydrophylic.
plot_amino_distribution(
position_in_sequence,
hydro_properties,
protein,
charge_colors,
interactive = getOption("hadex_use_interactive_plots")
)
position_in_sequence |
custom format |
hydro_properties |
data with hydrophobic properties |
protein |
chosen protein |
charge_colors |
vector of desired colors |
interactive |
|
The data for this function is not packaged yet.
a ggplot object.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.