| plot_overlap | R Documentation |
Generates overlapping peptide plot based on supplied data and parameters.
plot_overlap(dat, protein = dat[["Protein"]][1], state = dat[["State"]][1])
dat |
data imported by the |
protein |
protein included in calculations |
state |
state included in calculations |
The overlap plot presents all the peptides in given state on the protein sequence. This plot is visible in GUI.
a ggplot object.
read_hdx
show_overlap_data
plot_overlap(alpha_dat)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.