| plot_peptide_charge_measurement | R Documentation |
Plot the charge measurements from replicates for peptide in specific time point.
plot_peptide_charge_measurement(
dat,
protein = dat[["Protein"]][1],
state = dat[["State"]][1],
sequence = dat[["Sequence"]][1],
time_t = unique(dat[["Exposure"]])[3]
)
dat |
data as imported by the |
protein |
chosen protein. |
state |
biological state for chosen protein. |
sequence |
sequence of chosen peptide. |
time_t |
time point of the measurement. |
This function shows the measurements of charge from different replicates for specific peptide in specific state in specific time point of measurement on the plot.
a [ggplot2::ggplot()] object.
read_hdx
show_peptide_charge_measurement
plot_peptide_charge_measurement(alpha_dat)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.