| read_hdx | R Documentation |
Import HDX-MS datafile and validate its content
read_hdx(filename, separator = ",")
filename |
a file supplied by the user. Formats allowed: .csv, .xlsx and .xls. |
separator |
a value separating the columns. |
The function read_hdx generates a
dataset read from the supplied datafile. The files produced
by DynamX 3.0 or 2.0 in 'cluster data' format and 'tables'
file from HDeXaminer are handled.
Moreover, the data should include at least two replicates
of the experiment to calculate the uncertainty of the measurement.
For the files of HDeXaminer origin, the rows with no complete
information (e.q. missing 'Exp Cent' value) are removed. The 'Confidence'
column is preserved as the user should have impact on accepting rows based
on their Confidence flag. Moreover, those files need action from the user
- to confirm data processing (e.q. FD time point), choose accepted
confidence values and make some change of the labels using
update_hdexaminer_file function.
For further information check the documentation.
IMPORTANT! The files of HDeXaminer origin MUST be processed by
hand or by update_hdexaminer_file function to fit
the input of processing functions e.q. calculate_state_uptake
or calculate_diff_uptake.
a data.frame object
update_hdexaminer_file
create_control_dataset
calculate_state_uptake
dat <- read_hdx(system.file(package = "HaDeX2",
"HaDeX/data/alpha.csv"))
head(dat)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.