View source: R/reconstruct_sequence.R
| reconstruct_sequence | R Documentation |
Reconstruct protein sequence from experimental data
reconstruct_sequence(
dat,
protein = dat[["Protein"]][1],
states = unique(dat[["State"]]),
end = NULL
)
dat |
data read by |
protein |
selected protein |
states |
selected biological states for given protein |
end |
|
The function reconstruct_sequence
generates protein sequence from supplied experimental data.
For a position not covered, letter x is shown.
If the C-terminus of protein is not covered, there is a
possibility to manually fix the protein length by passing
a value to the 'end' parameter.
a character object.
read_hdx
reconstruct_sequence(alpha_dat)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.