| show_diff_uptake_data_confidence | R Documentation |
Present differential deuterium uptake values in selected form, accompanied by the significance
show_diff_uptake_data_confidence(
diff_uptake_dat,
theoretical = FALSE,
fractional = FALSE,
confidence_level = 0.98,
hybrid = FALSE
)
diff_uptake_dat |
data produced by |
theoretical |
|
fractional |
|
confidence_level |
confidence level for the test, from range [0, 1]. |
hybrid |
|
The function show_uptake_data generates a subsets
of the uptake dat based on selected parameters. It contains the information
if the value is statistically significant at selected confidence level.
The numerical values are rounded to 4 places. The names of columns
are changed to user-friendly ones.
a data.frame object
create_diff_uptake_dataset
plot_differential
diff_uptake_dat <- create_diff_uptake_dataset(alpha_dat)
show_diff_uptake_data_confidence(diff_uptake_dat)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.