| show_overlap_data | R Documentation |
Presents peptide overlap on protein sequence data, based on the supplied parameters.
show_overlap_data(
dat,
protein = dat[["Protein"]][1],
state = dat[["State"]][1],
start = min(dat[["Start"]]),
end = max(dat[["End"]])
)
dat |
data imported by the |
protein |
chosen protein. |
state |
biological state for chosen protein. |
start |
start position of chosen protein. |
end |
end position of chosen protein. |
The data frame presents all the peptides in given state, with its start and end position on the protein sequence. This data is available in the GUI.
a data.frame object.
read_hdx
plot_overlap
show_overlap_data(alpha_dat)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.