| show_peptide_mass_measurement | R Documentation |
Show the mass measurements from replicates for peptide in specific time point.
show_peptide_mass_measurement(
rep_mass_dat,
protein = rep_mass_dat[["Protein"]][1],
state = rep_mass_dat[["State"]][1],
sequence = rep_mass_dat[["Sequence"]][1],
time_t = unique(rep_mass_dat[["Exposure"]])[3]
)
rep_mass_dat |
data produced by
|
protein |
chosen protein. |
state |
biological state for chosen protein. |
sequence |
sequence of chosen peptide. |
time_t |
time point of the measurement. |
This function shows the measurements of mass from different replicates for specific peptide in specific state in specific time point of measurement.
a data.frame object.
read_hdx
calculate_exp_masses_per_replicate
calculate_exp_masses
calculate_state_uptake
calculate_diff_uptake
rep_mass_dat <- calculate_exp_masses_per_replicate(alpha_dat)
show_peptide_mass_measurement(rep_mass_dat)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.