| show_replicate_histogram_data | R Documentation |
Show histogram data on number of replicates per peptide in one or multiple time point of measurement.
show_replicate_histogram_data(rep_dat)
rep_dat |
replicate data, created by
|
The function shows the information about number of replicates for peptides in one or multiple time point of measurement, depends on supplied data.
a data.frame object.
create_replicate_dataset
plot_replicate_histogram
rep_dat <- create_replicate_dataset(alpha_dat)
show_replicate_histogram_data(rep_dat)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.