| show_summary_data | R Documentation |
Show summary table
show_summary_data(
dat,
confidence_level = "",
protein_length = max(dat[["End"]])
)
dat |
data imported by the |
confidence_level |
confidence level for the test, from range [0, 1]. |
protein_length |
the length of the protein sequence |
The format in the table is suggested by the community and should be provided for experimental data.
a data.table object
Masson, G.R., Burke, J.E., Ahn, N.G., Anand, G.S., Borchers, C., Brier, S., Bou-Assaf, G.M., Engen, J.R., Englander, S.W., Faber, J., et al. (2019). Recommendations for performing, interpreting and reporting hydrogen deuterium exchange mass spectrometry (HDX-MS) experiments. Nat Methods 16, 595–602
read_hdx
show_summary_data(alpha_dat)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.